@@ -6,5 +6,9 @@ class ChromeDriverVersionError(AdmittedError):
     """Problem during setup of ChromeDriver"""
 
 
+class ChromeDriverServiceError(AdmittedError):
+    """Problem with the ChromeDriver Service instance"""
+
+
 class NavigationError(AdmittedError):
     """Problem navigating to a new page"""
